Add

Struct Add 

pub struct Add<'a> { /* private fields */ }
Create an Add endpoint for posts.

https://pinboard.in/api/#posts_add

Arguments

This builder takes two required arguments.

  • url - URL of the bookmark
  • description - title or description of the bookmark

The remaining six arguments are optional.

  • extended - extended description of the bookmark
  • tags - vector of up to 100 tags
  • dt - creation time for this bookmark
  • replace - boolean indicating if this should replace existing bookmark (default: true)
  • shared - boolean to make the bookmark public
  • toread - boolean that marks the bookmark as toread

Note that if no dt is supplied, the date of the last bookmark will be used.

Example

let post_endpoint = Add::builder()
                    .url(Url::parse("https://example.com").unwrap())
                    .description("Example bookmark")
                    .build().unwrap();
assert_eq!(post_endpoint.endpoint(), "v1/posts/add");

Implementations

Source

impl<'a> Add<'a>

pub fn builder() -> AddBuilder<'a>

Create a builder for the endpoint