pub struct Add<'a> { /* private fields */ }Expand description
Create an Add endpoint for posts.
https://pinboard.in/api/#posts_add
Arguments
This builder takes two required arguments.
url- URL of the bookmarkdescription- title or description of the bookmark
The remaining six arguments are optional.
extended- extended description of the bookmarktags- vector of up to 100 tagsdt- creation time for this bookmarkreplace- boolean indicating if this should replace existing bookmark (default: true)shared- boolean to make the bookmark publictoread- boolean that marks the bookmark as toread
Note that if no dt is supplied, the date of the last bookmark will
be used.
Example
let post_endpoint = Add::builder()
.url(Url::parse("https://example.com").unwrap())
.description("Example bookmark")
.build().unwrap();
assert_eq!(post_endpoint.endpoint(), "v1/posts/add");Implementations